//
//  AASFSCopyObjectPreflightOperation.h
//  AASFilesystemTools
//
/* Copyright (c) 2001-2009, Andreas Schwarz
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 Neither the names of the Andreas Schwarz or immaterial nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#import <Cocoa/Cocoa.h>
#import "AASFSCopyObjectHandler.h"


@interface AASFSCopyObjectPreflightOperation : NSOperation {
	NSArray *urls;
	NSMutableArray *results;
	
	unsigned long long bytesCounted;
	NSUInteger filesCounted;
	
	NSTimer *delegateMessageTimer;
	SEL updateSelector;
		
	id delegate;
}

/* Array of urls for the files to preflight. Set this before adding the operation to an operation queue,never after the operation has already started. */
@property(copy) NSArray *urls;

/* Your delegate will read this when the update method is called to get any new status updates since the method was last called. May be nil or empty, but that alone does not mean the operation is finished - check isFinished. */
@property(readonly) NSArray *results;
@property(readonly) NSUInteger resultsCount;

/* The selector you want the operation to use when messaging your delegate. Selector should take one argument, which will be the AASFSCopyObjectPreflightOperation object that sent the message. */
@property(assign) SEL updateSelector;

/* The object that wants to keep informed of preflight progress. */
@property(assign) id delegate;



@end
